==> untahris-2.0-src.tgz: untahris/bullet.cpp <==
// Untahris (Common Playground)
// copyright (C) 2006 longuens@users.sourceforge.net
// Released under GNU General Public License (see the file COPYING)
// --------------------------------------------------------------
// Bullet.

struct OBullet : TPlayObject {
  public:
  int x;
  int y;
  int dx;
  int dy;
  OBullet(int _owner, int _x, int _y, int _dx, int _dy) : 
    x(_x), y(_y), dx(_dx), dy(_dy) {
    owner = _owner;
    time = g.time;
    g.objects.push_back(this);
    }
  OBullet(TBuffer &b) {
    b.get(owner); 
    b.get(x); b.get(y); b.get(dx); b.get(dy); b.get(time);
    }
  void save(TBuffer &b) {
    b.putChar(1);
    b.put(owner); 
    b.put(x); b.put(y); b.put(dx); b.put(dy); b.put(time);
    }
  void go() {
    x += dx;
    y += dy;
    int nx = DeCtr(x);
    int ny = DeCtr(y);
    if(nx<0) nx = 0;
    if(ny<0) ny = 0;
    if(nx>g.sizeX-1) nx = g.sizeX-1;
    if(ny>g.sizeY-1) ny = g.sizeY-1;
    if(destroyAt(nx,ny, owner)) {
      d.playSoundAt(d.sndHit, x, y);
      g.deleteObject(this); return;
      }
    for(int o=0; o<size(g.objects); o++) if(g.objects[o])
      if(g.objects[o]->reactToBullet(this)) {
        g.deleteObject(this);
        return;
        }
    time++;
    }
  void draw() {
    for(int q=0; q<128; q++) {
      d.putpix(CTG(x - dx*q/2 + dy), CTG(y - dy*q/2 - dx), ow()->color);
      d.putpix(CTG(x - dx*q/2 - dy), CTG(y - dy*q/2 + dx), ow()->color);
      d.putpix(CTG(x - dx*q/2), CTG(y - dy*q/2), 0xFFFFFF);
      }
    DIc(icBullet).drawAtCentered(CTG(x), CTG(y));
    }
  };

==> untahris-3.1-src.tgz: untahris/bullet.cpp <==
// Untahris (Common Playground)
// copyright (C) 2006 longuens@users.sourceforge.net
// Released under GNU General Public License (see the file COPYING)
// --------------------------------------------------------------
// Bullet.

struct OBullet : TPlayObject {
  public:
  int32 x;
  int32 y;
  int32 dx;
  int32 dy;
  OBullet(int _owner, int _x, int _y, int _dx, int _dy) : 
    x(_x), y(_y), dx(_dx), dy(_dy) {
    owner = _owner;
    time = g.time;
    g.objects.push_back(this);
    }
  OBullet(TBuffer &b) {
    b.get(owner); 
    b.get(x); b.get(y); b.get(dx); b.get(dy); b.get(time);
    }
  void save(TBuffer &b) {
    b.putChar(1);
    b.put(owner); 
    b.put(x); b.put(y); b.put(dx); b.put(dy); b.put(time);
    }
  void go() {
    x += dx;
    y += dy;
    int nx = DeCtr(x);
    int ny = DeCtr(y);
    if(nx<0) nx = 0;
    if(ny<0) ny = 0;
    if(nx>g.sizeX-1) nx = g.sizeX-1;
    if(ny>g.sizeY-1) ny = g.sizeY-1;
    if(destroyAt(nx,ny, owner)) {
      d.playSoundAt(d.sndHit, x, y);
      g.deleteObject(this); return;
      }
    for(int o=0; o<size(g.objects); o++) if(g.objects[o])
      if(g.objects[o]->reactToBullet(this)) {
        g.deleteObject(this);
        return;
        }
    time++;
    }
  void draw() {
    for(int q=0; q<128; q++) {
      d.putpix(d.ofsX + CTG(x - dx*q/2 + dy), d.ofsY + CTG(y - dy*q/2 - dx), ow()->color);
      d.putpix(d.ofsX + CTG(x - dx*q/2 - dy), d.ofsY + CTG(y - dy*q/2 + dx), ow()->color);
      d.putpix(d.ofsX + CTG(x - dx*q/2), d.ofsY + CTG(y - dy*q/2), 0xFFFFFF);
      }
    DIc(icBullet).drawAtCentered(CTG(x), CTG(y));
    }
  };
